{% extends 'diary/modal_base.html' %} {% block diary_nav %} {% with diary_nav_up=next diary_nav_prev='' diary_nav_next='' %} {{ block.super }} {% endwith %} {% endblock diary_nav %} {% block diary_title %} {{ customer }} Treatment History {% endblock diary_title %} {% block diary_content %} {{ block.super }}

#### Date

#### Time

#### Treatment

#### Notes

#### Cancel

#### No-Show

{% for entry in entries %}
{{ entry.date }}
{{ entry.time }}
{{ entry.treatment }}
{{ entry.notes }}
{{ entry.cancelled }}
{{ entry.no_show }}
{% endfor %}

{% if statistics %}

#### Summary

#### Total:

#### Attended:

#### Cancelled:

#### No-Show:

{{ statistics.total }}
{{ statistics.bookings }}
{{ statistics.cancelled }}
{{ statistics.no_show }}
{% endif %} {% endblock diary_content %}